dupin.preprocessing
-------------------

.. py:currentmodule:: dupin.preprocessing

.. rubric:: Details

.. automodule:: dupin.preprocessing

.. rubric:: Modules

.. toctree::
   :maxdepth: 1

   module-preprocessing-filter
   module-preprocessing-signal
   module-preprocessing-supervised
